function WriteSTL(tri, xyz, normals, name)
%
%
%       WriteSTL(tri, xyz, normals, name)

%       --Input
%       tri: a n-3 matrix containing indices to vertices in xyz
%       xyz: a m-3 matrix containing vertices positions
%       normals: a n-3 matrix containing vertices normals. It can be set to
%       empty, []
%       name: output file name as a string
%

if(~exist('normals', 'var'))
    normals = [];
end

if(isempty(normals))
   normals = ComputeFaceNormals(tri, xyz);
end

fid = fopen(name, 'w');

fprintf(fid, 'solid base\n');

for i=1:size(tri, 1)    
    fprintf(fid, 'facet normal %f %f %f\n', normals(i, 1),  normals(i, 2),  normals(i, 3));
    fprintf(fid, '    outer loop\n');
        
    i1 = tri(i, 1);
    i2 = tri(i, 2);
    i3 = tri(i, 3);
    
    fprintf(fid, '        vertex %f %f %f\n', xyz(i1, 1), xyz(i1, 2), xyz(i1, 3));
    fprintf(fid, '        vertex %f %f %f\n', xyz(i2, 1), xyz(i2, 2), xyz(i2, 3));
    fprintf(fid, '        vertex %f %f %f\n', xyz(i3, 1), xyz(i3, 2), xyz(i3, 3));

    fprintf(fid, '    endloop\n');
    fprintf(fid, 'endloop\n');
end
fprintf(fid, 'endsolid base\n');

fclose(fid);

end
