function RenderMesh(tri, xyz, colors, rendering_mode)
%
%   
%   RenderMesh(tri, xyz, colors, rendering_mode)
%
%       --Input
%       tri: a n-3 matrix containing indices to vertices in xyz
%       xyz: a m-3 matrix containing vertices positions
%       colors: a m-3 matrix containing vertices colors
%       rendering_mode: a string.
%                        'triangles' --> rendering solid triangles
%                        'points'    --> rendering points
%

if(~exist('colors', 'var'))
    colors = [];
end

if(isempty(colors))
    colors = 0.5 * ones(size(xyz, 1), 3);
end

if(~exist('rendering_mode', 'var'))
    rendering_mode = 'triangles';
end

if(isempty(tri))
    rendering_mode = 'points';    
end

switch rendering_mode
    case 'points'
        scatter3(xyz(:,1), xyz(:,2), xyz(:,3), [], colors, 'filled');
        
    case 'triangles'
        trisurf(tri, xyz(:,1), xyz(:,2), xyz(:,3), 'FaceColor', 'flat', 'FaceVertexCData', colors ,'EdgeColor', 'black');
end

end
